pecos.op\_processors.generic\_op\_processor
===========================================

.. automodule:: pecos.op_processors.generic_op_processor











   .. rubric:: Classes

   .. autosummary::

      GenericOpProc
